#[non_exhaustive]pub enum Error {
StackUnderflow(char),
TypeMismatch(char),
UnrecognizedFormatOption(char),
InvalidVariableName(char),
InvalidParameterIndex(char),
MalformedCharacterConstant,
IntegerConstantOverflow,
MalformedIntegerConstant,
FormatWidthOverflow,
FormatPrecisionOverflow,
FormatTypeMismatch,
}Expand description
Errors reported when expanding a string
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StackUnderflow(char)
The operator does not have required data on stack
TypeMismatch(char)
The data type on stack is not expected by the operator
UnrecognizedFormatOption(char)
Unknown or unsupported format option
InvalidVariableName(char)
Variable name is invalid
InvalidParameterIndex(char)
Parameter index is invalid
MalformedCharacterConstant
Character constant is invalid
IntegerConstantOverflow
Integer constant is too large
MalformedIntegerConstant
Integer constant is invalid
FormatWidthOverflow
Format width is too large
FormatPrecisionOverflow
FormatTypeMismatch
Argument type is incompatible with the format